==> quarkus-core-deployment-2.0.0.Final-sources.jar: io/quarkus/deployment/dev/testing/TestConfig$$accessor.java <==
package io.quarkus.deployment.dev.testing;
public final class TestConfig$$accessor {
    private TestConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_nativeImageWaitTime(Object __instance) {
        return ((TestConfig)__instance).nativeImageWaitTime;
    }
    @SuppressWarnings("unchecked")
    public static void set_nativeImageWaitTime(Object __instance, Object nativeImageWaitTime) {
        ((TestConfig)__instance).nativeImageWaitTime = (java.time.Duration)nativeImageWaitTime;
    }
    @SuppressWarnings("unchecked")
    public static Object get_nativeImageProfile(Object __instance) {
        return ((TestConfig)__instance).nativeImageProfile;
    }
    @SuppressWarnings("unchecked")
    public static void set_nativeImageProfile(Object __instance, Object nativeImageProfile) {
        ((TestConfig)__instance).nativeImageProfile = (String)nativeImageProfile;
    }
    @SuppressWarnings("unchecked")
    public static Object get_profile(Object __instance) {
        return ((TestConfig)__instance).profile;
    }
    @SuppressWarnings("unchecked")
    public static void set_profile(Object __instance, Object profile) {
        ((TestConfig)__instance).profile = (io.quarkus.deployment.dev.testing.TestConfig.Profile)profile;
    }
    @SuppressWarnings("unchecked")
    public static Object get_integrationJvmArgLine(Object __instance) {
        return ((TestConfig)__instance).integrationJvmArgLine;
    }
    @SuppressWarnings("unchecked")
    public static void set_integrationJvmArgLine(Object __instance, Object integrationJvmArgLine) {
        ((TestConfig)__instance).integrationJvmArgLine = (java.util.Optional<String>)integrationJvmArgLine;
    }
    @SuppressWarnings("unchecked")
    public static Object get_hangDetectionTimeout(Object __instance) {
        return ((TestConfig)__instance).hangDetectionTimeout;
    }
    @SuppressWarnings("unchecked")
    public static void set_hangDetectionTimeout(Object __instance, Object hangDetectionTimeout) {
        ((TestConfig)__instance).hangDetectionTimeout = (java.time.Duration)hangDetectionTimeout;
    }
    @SuppressWarnings("unchecked")
    public static Object get_type(Object __instance) {
        return ((TestConfig)__instance).type;
    }
    @SuppressWarnings("unchecked")
    public static void set_type(Object __instance, Object type) {
        ((TestConfig)__instance).type = (TestType)type;
    }
    @SuppressWarnings("unchecked")
    public static Object get_classClonePattern(Object __instance) {
        return ((TestConfig)__instance).classClonePattern;
    }
    @SuppressWarnings("unchecked")
    public static void set_classClonePattern(Object __instance, Object classClonePattern) {
        ((TestConfig)__instance).classClonePattern = (String)classClonePattern;
    }
}

==> quarkus-core-deployment-2.2.3.Final-sources.jar: io/quarkus/deployment/dev/testing/TestConfig$$accessor.java <==
package io.quarkus.deployment.dev.testing;
public final class TestConfig$$accessor {
    private TestConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_nativeImageProfile(Object __instance) {
        return ((TestConfig)__instance).nativeImageProfile;
    }
    @SuppressWarnings("unchecked")
    public static void set_nativeImageProfile(Object __instance, Object nativeImageProfile) {
        ((TestConfig)__instance).nativeImageProfile = (String)nativeImageProfile;
    }
    @SuppressWarnings("unchecked")
    public static Object get_profile(Object __instance) {
        return ((TestConfig)__instance).profile;
    }
    @SuppressWarnings("unchecked")
    public static void set_profile(Object __instance, Object profile) {
        ((TestConfig)__instance).profile = (io.quarkus.deployment.dev.testing.TestConfig.Profile)profile;
    }
    @SuppressWarnings("unchecked")
    public static Object get_argLine(Object __instance) {
        return ((TestConfig)__instance).argLine;
    }
    @SuppressWarnings("unchecked")
    public static void set_argLine(Object __instance, Object argLine) {
        ((TestConfig)__instance).argLine = (java.util.Optional<java.util.List<String>>)argLine;
    }
    @SuppressWarnings("unchecked")
    public static Object get_waitTime(Object __instance) {
        return ((TestConfig)__instance).waitTime;
    }
    @SuppressWarnings("unchecked")
    public static void set_waitTime(Object __instance, Object waitTime) {
        ((TestConfig)__instance).waitTime = (java.time.Duration)waitTime;
    }
    @SuppressWarnings("unchecked")
    public static Object get_hangDetectionTimeout(Object __instance) {
        return ((TestConfig)__instance).hangDetectionTimeout;
    }
    @SuppressWarnings("unchecked")
    public static void set_hangDetectionTimeout(Object __instance, Object hangDetectionTimeout) {
        ((TestConfig)__instance).hangDetectionTimeout = (java.time.Duration)hangDetectionTimeout;
    }
    @SuppressWarnings("unchecked")
    public static Object get_type(Object __instance) {
        return ((TestConfig)__instance).type;
    }
    @SuppressWarnings("unchecked")
    public static void set_type(Object __instance, Object type) {
        ((TestConfig)__instance).type = (TestType)type;
    }
    @SuppressWarnings("unchecked")
    public static Object get_classClonePattern(Object __instance) {
        return ((TestConfig)__instance).classClonePattern;
    }
    @SuppressWarnings("unchecked")
    public static void set_classClonePattern(Object __instance, Object classClonePattern) {
        ((TestConfig)__instance).classClonePattern = (String)classClonePattern;
    }
}
